@@ -146,6 +146,7 @@ def prepare_for_addHtaut(
     chains = sites.keys()
     ninsertions = -1
     inserted_block = None
+    already_inserted = []
     for line in content:
         if line.startswith("ATOM"):
             termini_trigger = False
@@ -177,13 +178,21 @@ def prepare_for_addHtaut(
                 else:
                     continue
 
-            if line[26] != " ":
-                if inserted_block != (resnumb, resname):
+            insertion_code = line[26]
+            if insertion_code.strip():
+                new_res_trigger = False
+                if inserted_block != insertion_code:
                     ninsertions += 1
-                inserted_block = (resnumb, resname)
+                    new_res_trigger = True
+
+                inserted_block = insertion_code
                 resnumb += insertion_offset + ninsertions
-            else:
-                ninsertions = -1
+
+                if new_res_trigger:
+                    while resnumb in already_inserted:
+                        resnumb += 1
+                    if resnumb not in already_inserted:
+                        already_inserted.append(resnumb)
 
             new_line = new_pdb_line(
                 anumb,
